==> arrow-instances-free-0.8.0-sources.jar: extension/arrow/free/instances/cofree/functor/CofreeFunctorInstance.kt <==
package arrow.free.instances.cofree.functor

import arrow.Kind
import arrow.core.Tuple2
import arrow.free.Cofree
import arrow.free.Cofree.Companion
import arrow.free.ForCofree
import arrow.free.instances.CofreeFunctorInstance
import kotlin.Function1
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.map(arg1: Function1<A, B>): Cofree<S, B> = arrow.free.Cofree.functor<S>().run {
  this@map.map<A, B>(arg1) as arrow.free.Cofree<S, B>
}

@JvmName("imap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): Cofree<S, B> = arrow.free.Cofree.functor<S>().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.free.Cofree<S, B>
}

@JvmName("lift")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> lift(arg0: Function1<A, B>): Function1<Kind<Kind<ForCofree, S>, A>, Kind<Kind<ForCofree, S>, B>> = arrow.free.Cofree
   .functor<S>()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.Kind<arrow.free.ForCofree, S>, A>, arrow.Kind<arrow.Kind<arrow.free.ForCofree, S>, B>>

@JvmName("void")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A> Kind<Kind<ForCofree, S>, A>.void(): Cofree<S, Unit> = arrow.free.Cofree.functor<S>().run {
  this@void.void<A>() as arrow.free.Cofree<S, kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.fproduct(arg1: Function1<A, B>): Cofree<S, Tuple2<A, B>> = arrow.free.Cofree.functor<S>().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.free.Cofree<S, arrow.core.Tuple2<A, B>>
}

@JvmName("as")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.`as`(arg1: B): Cofree<S, B> = arrow.free.Cofree.functor<S>().run {
  this@`as`.`as`<A, B>(arg1) as arrow.free.Cofree<S, B>
}

@JvmName("tupleLeft")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.tupleLeft(arg1: B): Cofree<S, Tuple2<B, A>> = arrow.free.Cofree.functor<S>().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.free.Cofree<S, arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.tupleRight(arg1: B): Cofree<S, Tuple2<A, B>> = arrow.free.Cofree.functor<S>().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.free.Cofree<S, arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, B, A : B> Kind<Kind<ForCofree, S>, A>.widen(): Cofree<S, B> = arrow.free.Cofree.functor<S>().run {
  this@widen.widen<B, A>() as arrow.free.Cofree<S, B>
}

fun <S> Companion.functor(): CofreeFunctorInstance<S> = object : arrow.free.instances.CofreeFunctorInstance<S> {  }

==> arrow-instances-free-0.8.2-sources.jar: extension/arrow/free/instances/cofree/functor/CofreeFunctorInstance.kt <==
package arrow.free.instances.cofree.functor

import arrow.Kind
import arrow.core.Tuple2
import arrow.free.Cofree
import arrow.free.Cofree.Companion
import arrow.free.ForCofree
import arrow.free.instances.CofreeFunctorInstance
import kotlin.Function1
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.map(arg1: Function1<A, B>): Cofree<S, B> = arrow.free.Cofree.functor<S>().run {
  this@map.map<A, B>(arg1) as arrow.free.Cofree<S, B>
}

@JvmName("imap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): Cofree<S, B> = arrow.free.Cofree.functor<S>().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.free.Cofree<S, B>
}

@JvmName("lift")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> lift(arg0: Function1<A, B>): Function1<Kind<Kind<ForCofree, S>, A>, Kind<Kind<ForCofree, S>, B>> = arrow.free.Cofree
   .functor<S>()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.Kind<arrow.free.ForCofree, S>, A>, arrow.Kind<arrow.Kind<arrow.free.ForCofree, S>, B>>

@JvmName("unit")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A> Kind<Kind<ForCofree, S>, A>.unit(): Cofree<S, Unit> = arrow.free.Cofree.functor<S>().run {
  this@unit.unit<A>() as arrow.free.Cofree<S, kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.fproduct(arg1: Function1<A, B>): Cofree<S, Tuple2<A, B>> = arrow.free.Cofree.functor<S>().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.free.Cofree<S, arrow.core.Tuple2<A, B>>
}

@JvmName("as")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.`as`(arg1: B): Cofree<S, B> = arrow.free.Cofree.functor<S>().run {
  this@`as`.`as`<A, B>(arg1) as arrow.free.Cofree<S, B>
}

@JvmName("tupleLeft")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.tupleLeft(arg1: B): Cofree<S, Tuple2<B, A>> = arrow.free.Cofree.functor<S>().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.free.Cofree<S, arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForCofree, S>, A>.tupleRight(arg1: B): Cofree<S, Tuple2<A, B>> = arrow.free.Cofree.functor<S>().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.free.Cofree<S, arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, B, A : B> Kind<Kind<ForCofree, S>, A>.widen(): Cofree<S, B> = arrow.free.Cofree.functor<S>().run {
  this@widen.widen<B, A>() as arrow.free.Cofree<S, B>
}

fun <S> Companion.functor(): CofreeFunctorInstance<S> = object : arrow.free.instances.CofreeFunctorInstance<S> {  }
